==> arrow-docs-0.7.3-sources.jar: arrow/optics/Person$$optics.kt <==
package `arrow`.`optics`

import arrow.core.left
import arrow.core.right
import arrow.core.toOption

inline val `arrow`.`optics`.`Person`.Companion.iso: arrow.optics.Iso<`arrow`.`optics`.`Person`, arrow.core.Tuple2<`kotlin`.`Int`?, `arrow`.`core`.`Option`<`arrow`.`optics`.`Address`>>> inline get()= arrow.optics.Iso(
  get = { person: `arrow`.`optics`.`Person` -> arrow.core.Tuple2(person.`age`, person.`address`) },
  reverseGet = { tuple: arrow.core.Tuple2<`kotlin`.`Int`?, `arrow`.`core`.`Option`<`arrow`.`optics`.`Address`>> -> `arrow`.`optics`.`Person`(tuple.a, tuple.b) }
)

inline val `arrow`.`optics`.`Person`.Companion.nullableAge: arrow.optics.Lens<`arrow`.`optics`.`Person`, `kotlin`.`Int`?> inline get()= arrow.optics.Lens(
  get = { person: `arrow`.`optics`.`Person` -> person.`age` },
  set = { value: `kotlin`.`Int`? ->
    { person: `arrow`.`optics`.`Person` ->
      person.copy(`age` = value)
    }
  }
)

inline val `arrow`.`optics`.`Person`.Companion.optionAddress: arrow.optics.Lens<`arrow`.`optics`.`Person`, `arrow`.`core`.`Option`<`arrow`.`optics`.`Address`>> inline get()= arrow.optics.Lens(
  get = { person: `arrow`.`optics`.`Person` -> person.`address` },
  set = { value: `arrow`.`core`.`Option`<`arrow`.`optics`.`Address`> ->
    { person: `arrow`.`optics`.`Person` ->
      person.copy(`address` = value)
    }
  }
)

inline val `arrow`.`optics`.`Person`.Companion.age: arrow.optics.Optional<`arrow`.`optics`.`Person`, `kotlin`.`Int`> inline get()= arrow.optics.Optional(
  getOrModify = { person: `arrow`.`optics`.`Person` -> person.`age`?.right() ?: person.left() },
  set = { value: `kotlin`.`Int` ->
    { person: `arrow`.`optics`.`Person` ->
      person.copy(`age` = value)
    }
  }
)

inline val `arrow`.`optics`.`Person`.Companion.address: arrow.optics.Optional<`arrow`.`optics`.`Person`, `arrow`.`optics`.`Address`> inline get()= arrow.optics.Optional(
  getOrModify = { person: `arrow`.`optics`.`Person` -> person.`address`.orNull()?.right() ?: person.left() },
  set = { value: `arrow`.`optics`.`Address` ->
    { person: `arrow`.`optics`.`Person` ->
      person.copy(`address` = value.toOption())
    }
  }
)

inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Person`>.age: arrow.optics.Optional<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Person`.age
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Person`>.age: arrow.optics.Optional<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Person`.age
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Person`>.age: arrow.optics.Optional<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Person`.age
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Person`>.age: arrow.optics.Optional<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Person`.age
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Person`>.age: arrow.optics.Setter<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Person`.age
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Person`>.age: arrow.optics.Traversal<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Person`.age
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Person`>.age: arrow.optics.Fold<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Person`.age

inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Person`>.address: arrow.optics.Optional<S, `arrow`.`optics`.`Address`> inline get() = this + `arrow`.`optics`.`Person`.address
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Person`>.address: arrow.optics.Optional<S, `arrow`.`optics`.`Address`> inline get() = this + `arrow`.`optics`.`Person`.address
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Person`>.address: arrow.optics.Optional<S, `arrow`.`optics`.`Address`> inline get() = this + `arrow`.`optics`.`Person`.address
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Person`>.address: arrow.optics.Optional<S, `arrow`.`optics`.`Address`> inline get() = this + `arrow`.`optics`.`Person`.address
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Person`>.address: arrow.optics.Setter<S, `arrow`.`optics`.`Address`> inline get() = this + `arrow`.`optics`.`Person`.address
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Person`>.address: arrow.optics.Traversal<S, `arrow`.`optics`.`Address`> inline get() = this + `arrow`.`optics`.`Person`.address
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Person`>.address: arrow.optics.Fold<S, `arrow`.`optics`.`Address`> inline get() = this + `arrow`.`optics`.`Person`.address

inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Person`>.nullableAge: arrow.optics.Lens<S, `kotlin`.`Int`?> inline get() = this + `arrow`.`optics`.`Person`.nullableAge
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Person`>.nullableAge: arrow.optics.Lens<S, `kotlin`.`Int`?> inline get() = this + `arrow`.`optics`.`Person`.nullableAge
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Person`>.nullableAge: arrow.optics.Optional<S, `kotlin`.`Int`?> inline get() = this + `arrow`.`optics`.`Person`.nullableAge
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Person`>.nullableAge: arrow.optics.Optional<S, `kotlin`.`Int`?> inline get() = this + `arrow`.`optics`.`Person`.nullableAge
inline val <S> arrow.optics.Getter<S, `arrow`.`optics`.`Person`>.nullableAge: arrow.optics.Getter<S, `kotlin`.`Int`?> inline get() = this + `arrow`.`optics`.`Person`.nullableAge
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Person`>.nullableAge: arrow.optics.Setter<S, `kotlin`.`Int`?> inline get() = this + `arrow`.`optics`.`Person`.nullableAge
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Person`>.nullableAge: arrow.optics.Traversal<S, `kotlin`.`Int`?> inline get() = this + `arrow`.`optics`.`Person`.nullableAge
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Person`>.nullableAge: arrow.optics.Fold<S, `kotlin`.`Int`?> inline get() = this + `arrow`.`optics`.`Person`.nullableAge

inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Person`>.optionAddress: arrow.optics.Lens<S, `arrow`.`core`.`Option`<`arrow`.`optics`.`Address`>> inline get() = this + `arrow`.`optics`.`Person`.optionAddress
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Person`>.optionAddress: arrow.optics.Lens<S, `arrow`.`core`.`Option`<`arrow`.`optics`.`Address`>> inline get() = this + `arrow`.`optics`.`Person`.optionAddress
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Person`>.optionAddress: arrow.optics.Optional<S, `arrow`.`core`.`Option`<`arrow`.`optics`.`Address`>> inline get() = this + `arrow`.`optics`.`Person`.optionAddress
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Person`>.optionAddress: arrow.optics.Optional<S, `arrow`.`core`.`Option`<`arrow`.`optics`.`Address`>> inline get() = this + `arrow`.`optics`.`Person`.optionAddress
inline val <S> arrow.optics.Getter<S, `arrow`.`optics`.`Person`>.optionAddress: arrow.optics.Getter<S, `arrow`.`core`.`Option`<`arrow`.`optics`.`Address`>> inline get() = this + `arrow`.`optics`.`Person`.optionAddress
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Person`>.optionAddress: arrow.optics.Setter<S, `arrow`.`core`.`Option`<`arrow`.`optics`.`Address`>> inline get() = this + `arrow`.`optics`.`Person`.optionAddress
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Person`>.optionAddress: arrow.optics.Traversal<S, `arrow`.`core`.`Option`<`arrow`.`optics`.`Address`>> inline get() = this + `arrow`.`optics`.`Person`.optionAddress
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Person`>.optionAddress: arrow.optics.Fold<S, `arrow`.`core`.`Option`<`arrow`.`optics`.`Address`>> inline get() = this + `arrow`.`optics`.`Person`.optionAddress

==> arrow-docs-0.10.3-sources.jar: arrow/optics/Person$$optics.kt <==
package `arrow`.`optics`

import arrow.core.left
import arrow.core.right
import arrow.core.toOption

inline val `arrow`.`optics`.`Person`.Companion.iso: arrow.optics.Iso<`arrow`.`optics`.`Person`, arrow.core.Tuple2<`kotlin`.`Int`?, `arrow`.`core`.`Option`<`arrow`.`optics`.`Address`>>> inline get()= arrow.optics.Iso(
  get = { person: `arrow`.`optics`.`Person` -> arrow.core.Tuple2(person.`age`, person.`address`) },
  reverseGet = { tuple: arrow.core.Tuple2<`kotlin`.`Int`?, `arrow`.`core`.`Option`<`arrow`.`optics`.`Address`>> -> `arrow`.`optics`.`Person`(tuple.a, tuple.b) }
)

inline val `arrow`.`optics`.`Person`.Companion.nullableAge: arrow.optics.Lens<`arrow`.`optics`.`Person`, `kotlin`.`Int`?> inline get()= arrow.optics.Lens(
  get = { person: `arrow`.`optics`.`Person` -> person.`age` },
  set = { person: `arrow`.`optics`.`Person`, value: `kotlin`.`Int`? -> person.copy(`age` = value) }
)

inline val `arrow`.`optics`.`Person`.Companion.optionAddress: arrow.optics.Lens<`arrow`.`optics`.`Person`, `arrow`.`core`.`Option`<`arrow`.`optics`.`Address`>> inline get()= arrow.optics.Lens(
  get = { person: `arrow`.`optics`.`Person` -> person.`address` },
  set = { person: `arrow`.`optics`.`Person`, value: `arrow`.`core`.`Option`<`arrow`.`optics`.`Address`> -> person.copy(`address` = value) }
)

inline val `arrow`.`optics`.`Person`.Companion.age: arrow.optics.Optional<`arrow`.`optics`.`Person`, `kotlin`.`Int`> inline get()= arrow.optics.Optional(
  getOrModify = { person: `arrow`.`optics`.`Person` -> person.`age`?.right() ?: person.left() },
  set = { person: `arrow`.`optics`.`Person`, value: `kotlin`.`Int` -> person.copy(`age` = value) }
)

inline val `arrow`.`optics`.`Person`.Companion.address: arrow.optics.Optional<`arrow`.`optics`.`Person`, `arrow`.`optics`.`Address`> inline get()= arrow.optics.Optional(
  getOrModify = { person: `arrow`.`optics`.`Person` -> person.`address`.orNull()?.right() ?: person.left() },
  set = { person: `arrow`.`optics`.`Person`, value: `arrow`.`optics`.`Address` -> person.copy(`address` = value.toOption()) }
)

inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Person`>.age: arrow.optics.Optional<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Person`.age
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Person`>.age: arrow.optics.Optional<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Person`.age
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Person`>.age: arrow.optics.Optional<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Person`.age
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Person`>.age: arrow.optics.Optional<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Person`.age
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Person`>.age: arrow.optics.Setter<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Person`.age
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Person`>.age: arrow.optics.Traversal<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Person`.age
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Person`>.age: arrow.optics.Fold<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Person`.age

inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Person`>.address: arrow.optics.Optional<S, `arrow`.`optics`.`Address`> inline get() = this + `arrow`.`optics`.`Person`.address
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Person`>.address: arrow.optics.Optional<S, `arrow`.`optics`.`Address`> inline get() = this + `arrow`.`optics`.`Person`.address
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Person`>.address: arrow.optics.Optional<S, `arrow`.`optics`.`Address`> inline get() = this + `arrow`.`optics`.`Person`.address
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Person`>.address: arrow.optics.Optional<S, `arrow`.`optics`.`Address`> inline get() = this + `arrow`.`optics`.`Person`.address
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Person`>.address: arrow.optics.Setter<S, `arrow`.`optics`.`Address`> inline get() = this + `arrow`.`optics`.`Person`.address
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Person`>.address: arrow.optics.Traversal<S, `arrow`.`optics`.`Address`> inline get() = this + `arrow`.`optics`.`Person`.address
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Person`>.address: arrow.optics.Fold<S, `arrow`.`optics`.`Address`> inline get() = this + `arrow`.`optics`.`Person`.address

inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Person`>.nullableAge: arrow.optics.Lens<S, `kotlin`.`Int`?> inline get() = this + `arrow`.`optics`.`Person`.nullableAge
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Person`>.nullableAge: arrow.optics.Lens<S, `kotlin`.`Int`?> inline get() = this + `arrow`.`optics`.`Person`.nullableAge
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Person`>.nullableAge: arrow.optics.Optional<S, `kotlin`.`Int`?> inline get() = this + `arrow`.`optics`.`Person`.nullableAge
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Person`>.nullableAge: arrow.optics.Optional<S, `kotlin`.`Int`?> inline get() = this + `arrow`.`optics`.`Person`.nullableAge
inline val <S> arrow.optics.Getter<S, `arrow`.`optics`.`Person`>.nullableAge: arrow.optics.Getter<S, `kotlin`.`Int`?> inline get() = this + `arrow`.`optics`.`Person`.nullableAge
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Person`>.nullableAge: arrow.optics.Setter<S, `kotlin`.`Int`?> inline get() = this + `arrow`.`optics`.`Person`.nullableAge
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Person`>.nullableAge: arrow.optics.Traversal<S, `kotlin`.`Int`?> inline get() = this + `arrow`.`optics`.`Person`.nullableAge
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Person`>.nullableAge: arrow.optics.Fold<S, `kotlin`.`Int`?> inline get() = this + `arrow`.`optics`.`Person`.nullableAge

inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Person`>.optionAddress: arrow.optics.Lens<S, `arrow`.`core`.`Option`<`arrow`.`optics`.`Address`>> inline get() = this + `arrow`.`optics`.`Person`.optionAddress
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Person`>.optionAddress: arrow.optics.Lens<S, `arrow`.`core`.`Option`<`arrow`.`optics`.`Address`>> inline get() = this + `arrow`.`optics`.`Person`.optionAddress
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Person`>.optionAddress: arrow.optics.Optional<S, `arrow`.`core`.`Option`<`arrow`.`optics`.`Address`>> inline get() = this + `arrow`.`optics`.`Person`.optionAddress
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Person`>.optionAddress: arrow.optics.Optional<S, `arrow`.`core`.`Option`<`arrow`.`optics`.`Address`>> inline get() = this + `arrow`.`optics`.`Person`.optionAddress
inline val <S> arrow.optics.Getter<S, `arrow`.`optics`.`Person`>.optionAddress: arrow.optics.Getter<S, `arrow`.`core`.`Option`<`arrow`.`optics`.`Address`>> inline get() = this + `arrow`.`optics`.`Person`.optionAddress
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Person`>.optionAddress: arrow.optics.Setter<S, `arrow`.`core`.`Option`<`arrow`.`optics`.`Address`>> inline get() = this + `arrow`.`optics`.`Person`.optionAddress
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Person`>.optionAddress: arrow.optics.Traversal<S, `arrow`.`core`.`Option`<`arrow`.`optics`.`Address`>> inline get() = this + `arrow`.`optics`.`Person`.optionAddress
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Person`>.optionAddress: arrow.optics.Fold<S, `arrow`.`core`.`Option`<`arrow`.`optics`.`Address`>> inline get() = this + `arrow`.`optics`.`Person`.optionAddress
